import os
import sys
import scripts
from GeminiQuery import GeminiQuery
from gemini_constants import *
import gemini_subjects
#from gemini_main import main
from version import __version__
